@@ -79,19 +79,30 @@ class ImageModuleTest(unittest.TestCase):
         os.remove(f_path)
 
     def testLoadJPG(self):
-        """ see if we can load a jpg.
+        """ to see if we can load a jpg.
         """
-
-        f = example_path("data/alien1.jpg")  # normalized
-        # f = os.path.join("examples", "data", "alien1.jpg")
+        f = example_path("data/alien1.jpg")
         surf = pygame.image.load(f)
 
         with open(f, "rb") as f:
             surf = pygame.image.load(f)
 
-        # with open(os.path.join("examples", "data", "alien1.jpg"), "rb") as f:
-        #     surf = pygame.image.load(open(os.path.join("examples", "data",
-        #         "alien1.jpg"), "rb"))
+    def testLoadBytesIO(self):
+        """ to see if we can load images with BytesIO.
+        """
+        files = [
+            "data/alien1.png",
+            "data/alien1.jpg",
+            "data/alien1.gif",
+            "data/asprite.bmp"
+        ]
+
+        for fname in files:
+            with self.subTest(fname=fname):
+                with open(example_path(fname), "rb") as f:
+                    img_bytes = f.read()
+                    img_file = io.BytesIO(img_bytes)
+                    image = pygame.image.load(img_file)
 
     def testSaveJPG(self):
         """ JPG equivalent to issue #211 - color channel swapping
@@ -831,7 +842,9 @@ class ImageModuleTest(unittest.TestCase):
         """can load different format images.
 
         We test loading the following file types:
-            bmp, png, jpg, gif (non-animated), tga (uncompressed), tif, xpm, ppm, pgm.
+            bmp, png, jpg, gif (non-animated), pcx, tga (uncompressed), tif, xpm, ppm, pgm
+        Following file types are tested when using SDL 2
+            svg, pnm, webp
         All the loaded images are smaller than 32 x 32 pixels.
         """
 
@@ -848,9 +861,16 @@ class ImageModuleTest(unittest.TestCase):
              ("grey.pgm", (120, 120, 120, 255))
         ]
 
+        if pygame.get_sdl_version()[0] >= 2:
+            filename_expected_color += [
+                ("teal.svg", (0, 128, 128, 255)),
+                ("crimson.pnm", (220, 20, 60, 255)),
+                ("scarlet.webp", (	252, 14, 53, 255))
+            ]
+
         for filename, expected_color in filename_expected_color:
             with self.subTest(
-                "Test loading a " + filename[-3:],
+                "Test loading a " + filename.split(".")[-1],
                 filename="examples/data/" + filename,
                 expected_color=expected_color
             ):
